#!/bin/bash

# 打印脚本的用途与使用方法
echo "#-------------------------------------------------------------------------#"
echo "这个脚本用于启动 Nmon 监控并执行 JMeter 压测，同时收集监控数据和压测结果。"
echo "使用方法: ./test.sh <basename>"
echo "选项:"
echo "  basename   指定结果文件的基本名称，比如输入 test 会取 test.jmx 作为输入，将结果放到 test.nmon"
echo ""
echo "#-------------------------------------------------------------------------#"
echo ""

# 检查参数是否为空
if [ -z "$1" ]; then
  echo "basename 不能为空"
  exit 1
fi

# 设置工作目录为脚本目录
script_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
cd "$script_dir"

# 默认结果文件基本名称
default_basename="test"

# 定义JMeter和Nmon的路径
jmeter_path="$HOME/jmeter/apache-jmeter-5.5/bin/jmeter"
nmon_path="$HOME/nmon16/nmon_x86_64_centos7"
nmonchart_path="$HOME/nmon16/nmonchart/nmonchart"

# 结果文件基本名称
basename="$1"

# JMX文件路径
jmx_file="$script_dir/${basename}.jmx"

# 检查JMX文件是否存在
if [ ! -f "$jmx_file" ]; then
  echo "找不到指定的JMX文件: $jmx_file"
  exit 1
fi

# 启动Nmon监控
nmon_output_file="$script_dir/${basename}.nmon"
echo "准备启动 nmon 监控...（$nmon_path -s 5 -c 1000 -F \"$nmon_output_file\" > /dev/null 2>&1 &）"
$nmon_path -t -s 2 -c 1000000 -F "$nmon_output_file" > /dev/null 2>&1 &

# 获取Nmon进程ID
nmon_pid=$!

# JMeter日志文件路径
jmeter_log_file="$script_dir/${basename}.jmeter.log"

# 启动JMeter进行压测，并指定结果文件路径
result_file="$script_dir/${basename}.jtl"
echo "准备启动 jmeter 测试...（$jmeter_path -n -t \"$jmx_file\" -l \"$result_file\"）"
$jmeter_path -n -t "$jmx_file" -l "$result_file" -j "$jmeter_log_file"

# 停止Nmon监控
echo "准备停止 nmon 监控进程 $nmon_pid"
if ps -p $nmon_pid > /dev/null; then
  kill $nmon_pid
fi

# 生成Nmon图表
nmon_chart_file="$script_dir/${basename}.nmonchart.html"
$nmonchart_path "$nmon_output_file" "$nmon_chart_file"

# 输出Nmon数据文件路径和JMeter结果文件路径
echo "用例 $basename 已执行完毕，请在当前目录 $script_dir 查看执行结果"

